==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/kmod/user_list/index.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

function KWL_UserList($index='',$link='',$where='',$out='',$plimit=15) {
   global $size,$page,$sort,$by;
   $CONF = KWL_GetConf();

   settype($page, "integer");
   $C['Content'] = "";
   
   if ($by=="uid" || $by=="name" || $by=="url" || $by=="rdate") {
      $link .= "&amp;sort=$sort&amp;by=$by";
      if ($sort=="asc") { $sort = "$by $sort"; $rsort = "desc"; } 
      else if ($sort=="desc") { $sort = "$by $sort"; $rsort = "asc"; } 
      else { $sort = "uid asc"; $rsort = "desc"; }
   } else { $sort = "uid asc"; $rsort = "desc"; }

   $sql = "FROM T_Users WHERE ";

   if (!empty($where) && !empty($index) && strlen(stripslashes($index))>=2) {
      $sql .= "($where LIKE \"%". $index ."%\") ORDER BY $sort";
      $link .= "&amp;where=$where";
   } else {
      if ($index == "other") {
         $sql .= "name REGEXP \"^\[1-9\.]\" ORDER BY $sort";
      } elseif (empty($index)) {
         $sql .= "uid > 0 ORDER BY $sort ";
      } else {
         if(KWL_CheckHangul($index)) {
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "ī";
            if($index == "ī") $r = "Ÿ";
            if($index == "Ÿ") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = chr(0xfe);
            $sql .= "binary name BETWEEN binary '$index' AND binary '$r'";
         } else $sql .= "name REGEXP \"^". $index ."\" ORDER BY $sort";
      }
   }
   
   if (empty($page)) $page = 1;
   $num_user = SqlResult("SELECT COUNT(*)" . $sql);
   $page_start = ($plimit * $page) - $plimit;
   
	$blah = KWL_npLink($num_user,$page,$link,$plimit);
   if ($blah) $C['Content'] = "<center> $blah </center>\n";
   
	$result = SqlQuery("SELECT * " . $sql . " LIMIT $page_start,$plimit");
   
	$C['Content'] .= $out->table_start("100%",'',1,0,3).
                  "<th><a href=\"$link&amp;sort=$rsort&amp;by=uid\">Uid</a></th>".
                  "<th><a href=\"$link&amp;sort=$rsort&amp;by=name\">". _NAME ."</a></th>".
                  "<th><a href=\"$link&amp;sort=$rsort&amp;by=url\">". _URL ."</a></th>".
                  "<th><a href=\"$link&amp;sort=$rsort&amp;by=rdate\">". _RDATE ."</a></th>";
   while ($A = mysql_fetch_array($result)) {
      if (!empty($A['url'])) $A['url'] = "<a href=\"$A[url]\" target=\"_blank\">$A[url]</a>";
      $C['Content'] .= "<tr>
         <td>$A[uid]</td>
         <td><a href=\"profiles.php?uid=$A[uid]\">". htmlspecialchars($A['name']) ."</a></td>
         <td>$A[url]&nbsp;</td>
         <td>". substr($A['rdate'],0,10) ."</td>";
   }
   $C['Content'] .= "</tr>". $out->table_end();
   $C['Heading'] = _USER_LIST .": ". sprintf(_USER_TOTAL_NUM, SqlCount("T_Users"));
   if ($blah) $C['Content'] .= "<center> $blah </center>\n";
   $C['Content'] = KWL_MakeUserIndex("user.php?what=userlist") . $C['Content'];
   KWL_DrawMain($C);
   unset($C);
   
   if (!empty($where)) $tmp = htmlspecialchars(stripslashes($index));
   else $tmp = "";
   $C['Heading'] = _FIND_USER;
   $C['Content'] = "<center><br />". $out->form_start("user.php","userlist").
                 $out->input_form("text","index",$tmp,$size['name'],60) ."&nbsp;".
                 $out->select("where", array( "name"     => _NAME,
                                              "url"      => _URL,
                                              "user_sig" => _USER_SIG,
                                              "profile"  => _USER_PROF ),
                              $where).
                 $out->input_form("hidden","what","userlist").
                 $out->input_form("submit",'',_FIND).
                 $out->form_end() . "</center><br />";
   KWL_DrawMain($C);
   unset($C);
}

function KWL_MakeUserIndex($link='') {
   $return = "| <a href=\"$link\">". _USER_LIST_ALL ."</a> | ";
   for($i=65; $i<=90; $i++) {
      $tmp = chr($i);
      $return .= "<a href=\"$link&amp;index=$tmp\">$tmp</a> | ";
      if ($i == 78) $return .= "<br /> | ";
   }
   $return .= "<br />";
   
	if (KWL_GetConf("Language") == "korean") {
      $han = array("1" => "", "2" => "", "3" => "", "4" => "",
                   "5" => "", "6" => "", "7" => "", "8" => "",
                   "9" => "", "10" => "", "11" => "ī", "12" => "Ÿ",
                   "13" => "", "14" => "");
      for($i=1;$i<=14;$i++) {
         $return .= " | <a href=\"$link&amp;index=$han[$i]\">$han[$i]</a>";
      }
   }
   $return .= " | <a href=\"$link&amp;index=other\">". _USER_LIST_ETC ."</a> |";
   return "<br /><center>$return</center><br />\n";
}
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/include/kmod/user_list/index.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

function KWL_UserList($index='',$link='',$where='',$out='',$plimit=15) {
   global $size,$page,$sort,$by;
   $CONF = KWL_GetConf();

   settype($page, "integer");
   $C['Content'] = "";
   
   if ($by=="uid" || $by=="name" || $by=="url" || $by=="rdate") {
      $link .= "&amp;sort=$sort&amp;by=$by";
      if ($sort=="asc") { $sort = "$by $sort"; $rsort = "desc"; } 
      else if ($sort=="desc") { $sort = "$by $sort"; $rsort = "asc"; } 
      else { $sort = "uid asc"; $rsort = "desc"; }
   } else { $sort = "uid asc"; $rsort = "desc"; }

   $sql = "FROM T_Users WHERE ";

   if (!empty($where) && !empty($index) && strlen(stripslashes($index))>=2) {
      $sql .= "($where LIKE \"%". $index ."%\") ORDER BY $sort";
      $link .= "&amp;where=$where";
   } else {
      if ($index == "other") {
         $sql .= "name REGEXP \"^\[1-9\.]\" ORDER BY $sort";
      } elseif (empty($index)) {
         $sql .= "uid > 0 ORDER BY $sort ";
      } else {
         if(KWL_CheckHangul($index)) {
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = "ī";
            if($index == "ī") $r = "Ÿ";
            if($index == "Ÿ") $r = "";
            if($index == "") $r = "";
            if($index == "") $r = chr(0xfe);
            $sql .= "binary name BETWEEN binary '$index' AND binary '$r'";
         } else $sql .= "name REGEXP \"^". $index ."\" ORDER BY $sort";
      }
   }
   
   if (empty($page)) $page = 1;
   $num_user = SqlResult("SELECT COUNT(*)" . $sql);
   $page_start = ($plimit * $page) - $plimit;
   
	$blah = KWL_npLink($num_user,$page,$link,$plimit);
   if ($blah) $C['Content'] = "<center> $blah </center>\n";
   
	$result = SqlQuery("SELECT * " . $sql . " LIMIT $page_start,$plimit");
   
	$C['Content'] .= $out->table_start("100%",'',1,0,3).
                  "<th><a href=\"$link&amp;sort=$rsort&amp;by=uid\">Uid</a></th>".
                  "<th><a href=\"$link&amp;sort=$rsort&amp;by=name\">". _NAME ."</a></th>".
                  "<th><a href=\"$link&amp;sort=$rsort&amp;by=url\">". _URL ."</a></th>".
                  "<th><a href=\"$link&amp;sort=$rsort&amp;by=rdate\">". _RDATE ."</a></th>";
   while ($A = mysql_fetch_array($result)) {
      if (!empty($A['url'])) $A['url'] = "<a href=\"$A[url]\" target=\"new\">$A[url]</a>";
      $C['Content'] .= "<tr>
         <td>$A[uid]</td>
         <td><a href=\"profiles.php?uid=$A[uid]\">". htmlspecialchars($A['name']) ."</a></td>
         <td>$A[url]&nbsp;</td>
         <td>". substr($A['rdate'],0,10) ."</td>";
   }
   $C['Content'] .= "</tr>". $out->table_end();
   $C['Heading'] = _USER_LIST .": ". sprintf(_USER_TOTAL_NUM, SqlCount("T_Users"));
   if ($blah) $C['Content'] .= "<center> $blah </center>\n";
   $C['Content'] = KWL_MakeUserIndex("user.php?what=userlist") . $C['Content'];
   KWL_DrawMain($C);
   unset($C);
   
   if (!empty($where)) $tmp = htmlspecialchars(stripslashes($index));
   else $tmp = "";
   $C['Heading'] = _FIND_USER;
   $C['Content'] = "<center><br />". $out->form_start("user.php","userlist").
                 $out->input_form("text","index",$tmp,$size['name'],60) ."&nbsp;".
                 $out->select("where", array( "name"     => _NAME,
                                              "url"      => _URL,
                                              "user_sig" => _USER_SIG,
                                              "profile"  => _USER_PROF ),
                              $where).
                 $out->input_form("hidden","what","userlist").
                 $out->input_form("submit",'',_FIND).
                 $out->form_end() . "</center><br />";
   KWL_DrawMain($C);
   unset($C);
}

function KWL_MakeUserIndex($link='') {
   $return = "| <a href=\"$link\">". _USER_LIST_ALL ."</a> | ";
   for($i=65; $i<=90; $i++) {
      $tmp = chr($i);
      $return .= "<a href=\"$link&amp;index=$tmp\">$tmp</a> | ";
      if ($i == 78) $return .= "<br /> | ";
   }
   $return .= "<br />";
   
	if (KWL_GetConf("Language") == "korean") {
      $han = array("1" => "", "2" => "", "3" => "", "4" => "",
                   "5" => "", "6" => "", "7" => "", "8" => "",
                   "9" => "", "10" => "", "11" => "ī", "12" => "Ÿ",
                   "13" => "", "14" => "");
      for($i=1;$i<=14;$i++) {
         $return .= " | <a href=\"$link&amp;index=$han[$i]\">$han[$i]</a>";
      }
   }
   $return .= " | <a href=\"$link&amp;index=other\">". _USER_LIST_ETC ."</a> |";
   return "<br /><center>$return</center><br />\n";
}
?>
